powered by
Extract file raw name and type from file names
Get file extensions without file names
file_name(filepath)file_type(filepath)
file_type(filepath)
Character vector. File path(s) to get file raw names without extension nor path OR extension without path nor raw name.
Other Data Wrangling: balance_data(), categ_reducer(), cleanText(), date_cuts(), date_feats(), formatHTML(), holidays(), impute(), left(), normalize(), num_abbr(), ohe_commas(), ohse(), quants(), removenacols(), replaceall(), replacefactor(), textFeats(), textTokenizer(), vector2text(), year_month(), zerovar()
balance_data()
categ_reducer()
cleanText()
date_cuts()
date_feats()
formatHTML()
holidays()
impute()
left()
normalize()
num_abbr()
ohe_commas()
ohse()
quants()
removenacols()
replaceall()
replacefactor()
textFeats()
textTokenizer()
vector2text()
year_month()
zerovar()
file_name("file.aux") file_name("temp/file.R") file_name("/temp/temp3/music.mp3") file_type("file.aux") file_type("temp/file.R") file_type("/temp/temp3/music.mp3")
Run the code above in your browser using DataLab