Skip to contents

This function lets the user scrap https://db-ip.com/ given IP address(es) to get their associated address type, ASN, ISP, organization, country, state or region, county, city, ZIP postal code, weather station, coordinates, Timezone, local time, languages, and currency.

Usage

ip_data(ip = myip(), quiet = FALSE)

Arguments

ip

Vector. Vector with all IP's we wish to search.

quiet

Boolean. Do not show the loading statusbar?

Value

data.frame. Each row is an unique ip address, and columns will bee created for all the additional information found.

Examples

# \donttest{
ip_data("163.114.132.0")
#>              id addresstype                   asn          isp connection
#> 1 163.114.132.0        IPv4 54115 - FACEBOOK-CORP Facebook Inc    Hosting
#>    organization       country stateregion        city zippostalcode
#> 1 Facebook Corp United States  California Santa Clara         95052
#>           weatherstation       coordinates                    timezone
#> 1 USCA1018 - Santa Clara 37.3541, -121.955 America/Los_Angeles (UTC-7)
#>   localtime             languages     currency
#> 1           en-US, es-US, haw, fr Dollar (USD)
ip_data(ip = c(myip(), "201.244.197.199"), quiet = TRUE)
#>                id addresstype                                asn
#> 1  128.24.161.179        IPv4 8075 - MICROSOFT-CORP-MSN-AS-BLOCK
#> 2 201.244.197.199        IPv4                    19429 - AS19429
#>                     isp connection      organization       country stateregion
#> 1 Microsoft Corporation    Hosting Microsoft Limited United States     Wyoming
#> 2        ETB - Colombia       <NA>              <NA>      Colombia Bogota D.C.
#>   districtcounty            city zippostalcode            weatherstation
#> 1        Laramie        Cheyenne         82002       USWY0032 - Cheyenne
#> 2   Bogotá  D.C. Barrio San Luis          <NA> COXX7742 - Vereda El Hato
#>         coordinates               timezone localtime             languages
#> 1    41.14, -104.82 America/Denver (UTC-6)           en-US, es-US, haw, fr
#> 2 4.66779, -74.0215 America/Bogota (UTC-5)                           es-CO
#>       currency                                   hostname
#> 1 Dollar (USD)                                       <NA>
#> 2   Peso (COP) dynamic-201-244-197-199.dynamic.etb.net.co
# }