This function lets the user scrap https://db-ip.com/ given IP address(es) to get their associated address type, ASN, ISP, organization, country, state or region, county, city, ZIP postal code, weather station, coordinates, Timezone, local time, languages, and currency.
Usage
ip_data(ip = myip(), quiet = FALSE)Value
data.frame. Each row is an unique ip address,
and columns will bee created for all the additional information found.
See also
Other Tools:
autoline(),
bind_files(),
bring_api(),
cal_split(),
chr2num(),
db_download(),
db_upload(),
dont_sleep(),
export_plot(),
export_results(),
files_functions(),
font_exists(),
formatColoured(),
formatHTML(),
glued(),
grepm(),
h2o_selectmodel(),
haveInternet(),
image_metadata(),
importxlsx(),
json2vector(),
list_cats(),
listfiles(),
mail_send(),
markdown2df(),
move_files(),
msplit(),
myip(),
quiet(),
read.file(),
statusbar(),
tic(),
try_require(),
updateLares(),
warnifnot(),
what_size()
Other Scrapper:
filesGD(),
gtrends_related(),
holidays(),
mp3_get(),
readGS(),
splot_summary(),
stocks_quote()
Examples
# \donttest{
ip_data("163.114.132.0")
#> id addresstype asn isp connection
#> 1 163.114.132.0 IPv4 54115 - FACEBOOK-CORP Facebook Inc Hosting
#> organization country stateregion city zippostalcode
#> 1 Facebook Corp United States California Santa Clara 95052
#> weatherstation coordinates timezone
#> 1 USCA1018 - Santa Clara 37.3541, -121.955 America/Los_Angeles (UTC-7)
#> localtime languages currency
#> 1 en-US, es-US, haw, fr Dollar (USD)
ip_data(ip = c(myip(), "201.244.197.199"), quiet = TRUE)
#> id addresstype asn
#> 1 128.24.161.179 IPv4 8075 - MICROSOFT-CORP-MSN-AS-BLOCK
#> 2 201.244.197.199 IPv4 19429 - AS19429
#> isp connection organization country stateregion
#> 1 Microsoft Corporation Hosting Microsoft Limited United States Wyoming
#> 2 ETB - Colombia <NA> <NA> Colombia Bogota D.C.
#> districtcounty city zippostalcode weatherstation
#> 1 Laramie Cheyenne 82002 USWY0032 - Cheyenne
#> 2 Bogotá D.C. Barrio San Luis <NA> COXX7742 - Vereda El Hato
#> coordinates timezone localtime languages
#> 1 41.14, -104.82 America/Denver (UTC-6) en-US, es-US, haw, fr
#> 2 4.66779, -74.0215 America/Bogota (UTC-5) es-CO
#> currency hostname
#> 1 Dollar (USD) <NA>
#> 2 Peso (COP) dynamic-201-244-197-199.dynamic.etb.net.co
# }