Learn R Programming

lares (version 5.4.1)

ip_data: Fetch IP address geolocation data

Description

This function queries geolocation APIs (such as freeipapi.com and db-ip.com) for given IP address(es) to retrieve associated location and network information including country, region, city, coordinates, timezone, currency, and ASN.

Usage

ip_data(ip = myip(), quiet = FALSE)

Value

data.frame. Each row is an unique ip address, and columns will be created for all the additional information found.

Arguments

ip

Vector. Vector with all IP's we wish to search.

quiet

Boolean. Do not show the loading statusbar?

See Also

Other Tools: autoline(), bind_files(), bring_api(), cal_split(), chr2num(), db_download(), db_upload(), dont_sleep(), export_plot(), export_results(), files_functions(), font_exists(), formatColoured(), formatHTML(), glued(), grepm(), h2o_selectmodel(), haveInternet(), image_metadata(), importxlsx(), json2vector(), list_cats(), listfiles(), mail_send(), markdown2df(), move_files(), msplit(), myip(), quiet(), read.file(), statusbar(), tic(), try_require(), updateLares(), warnifnot(), what_size()

Other Scrapper: filesGD(), gtrends_related(), holidays(), mp3_get(), readGS(), splot_summary(), stocks_quote()

Examples

Run this code
if (FALSE) {
ip_data("163.114.132.0")
ip_data(ip = c(myip(), "201.244.197.199"), quiet = TRUE)
}

Run the code above in your browser using DataLab