scale_x_comma: Axis scales format
Description
The `_comma` ones set comma format for axis text, the `_percent`
ones set percent format for axis text, and `_dollar` for collar currency
Usage
scale_x_comma(...)scale_y_comma(...)
scale_x_percent(...)
scale_y_percent(...)
scale_x_dollar(...)
scale_y_dollar(...)
Arguments
...
Arguments passed to `ggplot2::continuous_scale`